@@ -274,14 +274,14 @@ class TestPOFile(test_base.TestTranslationStore):
         for version, output in versions:
             if actual_version >= version:
                 print(
-                    f"Detected gettext {'.'.join(map(str, version))} or newer ({actual_version})"
+                    f"Detected gettext {'.'.join(map(str, version))} or newer ({actual_version})"  # ty:ignore[invalid-argument-type]
                 )
                 return output
 
         # Fallback to the oldest version
         oldest_version, oldest_output = versions[-1]
         print(
-            f"Detected gettext older than {'.'.join(map(str, oldest_version))} ({actual_version})"
+            f"Detected gettext older than {'.'.join(map(str, oldest_version))} ({actual_version})"  # ty:ignore[invalid-argument-type]
         )
         return oldest_output
 
@@ -340,6 +340,31 @@ msgstr "TRANSLATED-STRING"'''
         print(pofile)
         assert len(pofile.units) == 2
 
+    def test_parse_comment(self) -> None:
+        """Parse a string."""
+        posource = 'msgid "test"\nmsgstr "rest" # comment\n'
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 1
+        unit = pofile.units[0]
+        assert unit.source == "test"
+        assert unit.target == "rest"
+
+    def test_plurals_missing_plural(self) -> None:
+        posource = r"""msgid "Cow"
+msgstr[0] "Koei"
+msgstr[1] "Koeie"
+"""
+        with raises(ValueError):
+            self.poparse(posource)
+
+    def test_plurals_missing_array(self) -> None:
+        posource = r"""msgid "Cow"
+msgid_plural "Cows"
+msgstr "Koei"
+"""
+        with raises(ValueError):
+            self.poparse(posource)
+
     def test_plurals(self) -> None:
         posource = r"""msgid "Cow"
 msgid_plural "Cows"
@@ -349,6 +374,8 @@ msgstr[1] "Koeie"
         pofile = self.poparse(posource)
         assert len(pofile.units) == 1
         unit = pofile.units[0]
+        assert isinstance(unit.source, multistring)
+        assert unit.source.strings == ["Cow", "Cows"]
         assert isinstance(unit.target, multistring)
         print(unit.target.strings)
         assert unit.target == "Koei"
@@ -1466,3 +1493,8 @@ msgstr "next translation"
         # This should raise an error because it's genuinely invalid
         with raises(ValueError):
             self.poparse(posource)
+
+    def test_parse_corrupt_header(self) -> None:
+        posource = b'msgid ""\r\nmsgstr ""\r\n"PO-Revision-Date: 2025-11-27 05:03+0000\\n"\r\n"Last-Translator: \\"x\\" <x@example.com>\\n"\r\n"Language-Team: X"\r\n"MIME-Version: 1.0"\r\n"Content-Type: text/plain; charset=UTF-8"\r\n"Content-Transfer-Encoding: 8bit"\r\n'
+        with raises(ValueError):
+            self.poparse(posource)
