@@ -46,8 +46,8 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
             metavar="INPUT",
             help="read from INPUT (directory or file(s)) in po format",
         )
-        inputoption.optionalswitch = True
-        inputoption.required = True
+        inputoption.optionalswitch = True  # ty:ignore[unresolved-attribute]
+        inputoption.required = True  # ty:ignore[unresolved-attribute]
         self.define_option(inputoption)
         outputoption = optrecurse.optparse.Option(
             "-o",
@@ -57,8 +57,8 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
             metavar="OUTPUT",
             help="write to OUTPUT (directory) in po format",
         )
-        outputoption.optionalswitch = True
-        outputoption.required = True
+        outputoption.optionalswitch = True  # ty:ignore[unresolved-attribute]
+        outputoption.required = True  # ty:ignore[unresolved-attribute]
         self.define_option(outputoption)
 
     def parse_args(self, args=None, values=None):
@@ -107,7 +107,7 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
                     self.error(
                         optrecurse.optparse.OptionValueError(
                             "Output directory does not exist, attempt to create failed"
-                        )
+                        )  # ty:ignore[invalid-argument-type]
                     )
             if isinstance(options.input, list):
                 inputfiles = self.recurseinputfilelist(options)
@@ -144,7 +144,7 @@ class ConflictOptionParser(optrecurse.RecursiveOptionParser):
             string = string.replace(accelerator, "")
         return string.strip()
 
-    def processfile(self, fileprocessor, options, fullinputpath) -> bool:
+    def processfile(self, fileprocessor, options, fullinputpath) -> bool:  # ty:ignore[invalid-method-override]
         """Process an individual file."""
         inputfile = self.openinputfile(options, fullinputpath)
         inputfile = factory.getobject(inputfile)
